@@ -11,11 +11,16 @@
 
 
 SCD_effect_sizes <- function(browser = TRUE) {
-  if (!requireNamespace("shiny", quietly = TRUE)) {
-    stop("The simulator requires the shiny package. Please install it.", call. = FALSE)
-  }
-  if (!requireNamespace("ggplot2", quietly = TRUE)) {
-    stop("The simulator requires the ggplot2 package. Please install it.", call. = FALSE)
+  
+  req_pkgs <- c("shiny", "ggplot2", "markdown", "tidyr", "dplyr", "readxl", 
+                "janitor", "rlang", "glue", "rclipboard")
+  missing_pkgs <- unlist(lapply(req_pkgs, check_for_package))
+  
+  if (length(missing_pkgs) > 1) {
+    missing_pkgs <- paste(missing_pkgs, collapse = ", ")
+    stop(paste0("The SingleCaseES app requires the following packages: ", missing_pkgs,". Please install them."), call. = FALSE)
+  } else if (length(missing_pkgs) == 1) {
+    stop(paste("The SingleCaseES app requires the", missing_pkgs,"package. Please install it."), call. = FALSE)
   }
   
   appDir <- system.file("shiny-examples", "SCD-effect-sizes", package = "SingleCaseES")
@@ -28,3 +33,7 @@ SCD_effect_sizes <- function(browser = TRUE) {
   shiny::runApp(appDir, display.mode = "normal", launch.browser = browser)
 }
 
+check_for_package <- function(pkg) {
+  req <- requireNamespace(pkg, quietly = TRUE)
+  if (!req) pkg else NULL
+}
