@@ -17,7 +17,7 @@ Shogren <- Shogren %>%
 
 
 ShogrenSMD <- batch_calc_ES(dat = Shogren,
-                            grouping = vars(Study, Measure, Case),
+                            grouping = c(Study, Measure, Case),
                             condition = Phase,
                             baseline_phase = "No Choice",
                             outcome = outcome,
@@ -34,7 +34,7 @@ ShogrenSMD <- batch_calc_ES(dat = Shogren,
 
 Shogren_LRR_LOR_PND <- 
   batch_calc_ES(dat = Shogren,
-                grouping = vars(Study, Measure, Case),
+                grouping = c(Study, Measure, Case),
                 condition = Phase,
                 baseline_phase = "No Choice",
                 outcome = outcome,
